## $Id: interfaces.py 12078 2014-11-28 08:24:49Z henrik $
##
## Copyright (C) 2014 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
from zope.interface import Attribute, Interface
from zope import schema
from waeup.ikoba.interfaces import (
    IIkobaObject,
    ContextualDictSourceFactoryBase)
from waeup.ikoba.interfaces import MessageFactory as _

class AppCatSource(ContextualDictSourceFactoryBase):
    """A application category source delivers all application categories
    provided in the portal.
    """
    #: name of dict to deliver from kofa utils.
    DICT_NAME = 'APP_CATS_DICT'

class IProductsContainer(IIkobaObject):
    """A container for all kind of product objects.

    """

    def addProduct(product):
        """Add a product.
        """

class IProduct(IIkobaObject):
    """A base representation of products.

    """
    product_id = schema.TextLine(
        title = _(u'Product Id'),
        default = u'NA',
        required = True,
        )

    title = schema.TextLine(
        title = _(u'Product Title'),
        required = True,
        default = u'Unnamed',
        )

    application_category = schema.Choice(
        title = _(u'Application Category'),
        source = AppCatSource(),
        default = u'license',
        required = True,
        )
